.. _framework-integration:

Framework integration
=====================

Integration with Chameleon is available for a number of popular web
frameworks.

Pyramid
-------

Chameleon is the default template engine for the `Pyramid
<http://pylonsproject.org/projects/pyramid/about>`_ framework. See the
section on `Zope Page Templates
<http://docs.pylonsproject.org/projects/pyramid/1.0/narr/templates.html#chameleon-zpt-templates>`_
in the documentation for that project.

Zope 2 / Five
-------------

The `five.pt <http://pypi.python.org/pypi/five.pt>`_ package works as
a drop-in replacement to the standard template engine.

CMF / Plone
-----------

If your application uses the CMF content management framework
(including `Plone <http://www.plone.org>`_), the `cmf.pt
<http://pypi.python.org/pypi/cmf.pt>`_ package contains the required
support.

Zope Toolkit (ZTK)
------------------

For applications based on the `Zope Toolkit
<http://docs.zope.org/zopetoolkit/>`_ (ZTK), install and include the
`z3c.pt <http://pypi.python.org/pypi/z3c.pt>`_ package.


